@@ -17,6 +17,7 @@ from tendenci.core.event_logs.models import EventLog
 from tendenci.core.meta.models import Meta as MetaTags
 from tendenci.core.meta.forms import MetaForm
 from tendenci.core.site_settings.utils import get_setting
+from tendenci.core.perms.decorators import is_enabled
 from tendenci.core.perms.utils import (get_notice_recipients, update_perms_and_save,
     has_perm, get_query_filters, has_view_perm)
 from tendenci.core.categories.forms import CategoryForm, CategoryForm2
@@ -35,6 +36,7 @@ except:
 from tendenci.core.base.utils import send_email_notification
 
 
+@is_enabled('jobs')
 def detail(request, slug=None, template_name="jobs/view.html"):
     if not slug:
         return HttpResponseRedirect(reverse('jobs'))
@@ -50,6 +52,7 @@ def detail(request, slug=None, template_name="jobs/view.html"):
         raise Http403
 
 
+@is_enabled('jobs')
 def search(request, template_name="jobs/search.html"):
     query = request.GET.get('q', None)
     my_pending_jobs = request.GET.get('my_pending_jobs', False)
@@ -93,6 +96,7 @@ def search_redirect(request):
     return HttpResponseRedirect(reverse('jobs'))
 
 
+@is_enabled('jobs')
 def my_jobs(request, template_name = "jobs/my_jobs.html"):
     query = request.GET.get('q', None)
     if not request.user.is_anonymous():
@@ -112,6 +116,8 @@ def my_jobs(request, template_name = "jobs/my_jobs.html"):
     else:
         return HttpResponseRedirect(reverse('jobs'))
 
+
+@is_enabled('jobs')
 def print_view(request, slug, template_name="jobs/print-view.html"):
     job = get_object_or_404(Job, slug=slug)
 
@@ -125,9 +131,12 @@ def print_view(request, slug, template_name="jobs/print-view.html"):
     else:
         raise Http403
 
+
+@is_enabled('jobs')
 @login_required
 def add(request, form_class=JobForm, template_name="jobs/add.html",
         object_type=Job, success_redirect='job'):
+
     require_payment = get_setting('module', 'jobs',
                                     'jobsrequirespayment')
 
@@ -278,6 +287,7 @@ def add(request, form_class=JobForm, template_name="jobs/add.html",
             context_instance=RequestContext(request))
 
 
+@is_enabled('jobs')
 @login_required
 def edit(request, id, form_class=JobForm, template_name="jobs/edit.html", object_type=Job, success_redirect='job'):
     job = get_object_or_404(Job, pk=id)
@@ -362,9 +372,9 @@ def edit(request, id, form_class=JobForm, template_name="jobs/edit.html", object
         'form': form,
         'categoryform': categoryform
         }, context_instance=RequestContext(request))
-    
 
 
+@is_enabled('jobs')
 @login_required
 def edit_meta(request, id, form_class=MetaForm,
                     template_name="jobs/edit-meta.html"):
@@ -399,6 +409,7 @@ def edit_meta(request, id, form_class=MetaForm,
         context_instance=RequestContext(request))
 
 
+@is_enabled('jobs')
 @login_required
 def delete(request, id, template_name="jobs/delete.html"):
     job = get_object_or_404(Job, pk=id)
@@ -429,6 +440,7 @@ def delete(request, id, template_name="jobs/delete.html"):
         raise Http403
 
 
+@is_enabled('jobs')
 @login_required
 def pricing_add(request, form_class=JobPricingForm,
                     template_name="jobs/pricing-add.html"):
@@ -453,6 +465,7 @@ def pricing_add(request, form_class=JobPricingForm,
         raise Http403
 
 
+@is_enabled('jobs')
 @login_required
 def pricing_edit(request, id, form_class=JobPricingForm,
                     template_name="jobs/pricing-edit.html"):
@@ -479,6 +492,7 @@ def pricing_edit(request, id, form_class=JobPricingForm,
         context_instance=RequestContext(request))
 
 
+@is_enabled('jobs')
 @login_required
 def pricing_view(request, id, template_name="jobs/pricing-view.html"):
     job_pricing = get_object_or_404(JobPricing, id=id)
@@ -491,6 +505,7 @@ def pricing_view(request, id, template_name="jobs/pricing-view.html"):
         raise Http403
 
 
+@is_enabled('jobs')
 @login_required
 def pricing_delete(request, id, template_name="jobs/pricing-delete.html"):
     job_pricing = get_object_or_404(JobPricing, pk=id)
@@ -511,6 +526,7 @@ def pricing_delete(request, id, template_name="jobs/pricing-delete.html"):
         context_instance=RequestContext(request))
 
 
+@is_enabled('jobs')
 def pricing_search(request, template_name="jobs/pricing-search.html"):
     job_pricings = JobPricing.objects.all().order_by('duration')
 
@@ -519,6 +535,7 @@ def pricing_search(request, template_name="jobs/pricing-search.html"):
         context_instance=RequestContext(request))
 
 
+@is_enabled('jobs')
 @login_required
 def pending(request, template_name="jobs/pending.html"):
     can_view_jobs = has_perm(request.user, 'jobs.view_job')
@@ -584,6 +601,8 @@ def approve(request, id, template_name="jobs/approve.html"):
 def thank_you(request, template_name="jobs/thank-you.html"):
     return render_to_response(template_name, {}, context_instance=RequestContext(request))
 
+
+@is_enabled('jobs')
 @login_required
 def export(request, template_name="jobs/export.html"):
     """Export Jobs"""
